ControllerCaller class

Implementers

Constructors

ControllerCaller()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cardRequest({required String email, required String amount, required String currency, required String authData}) Future
getPaymentInfo({required String token, required String paymentCode}) Future
getQRCodePaymentStatus({required String tnxRef}) Future
getUSSDPaymentStatus({required String tnxRef}) Future
getVirtualAccountPaymentStatus({required String tnxRef}) Future
initializePayment({required String email, required int amount, required String currency}) Future
initializeQRCodePayment({required String merchantRef}) Future
initializeTransaction({required String email, required String currency, required String amount}) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payWithUSSD({required String tnxRef}) Future
recurringPaymentWithCard({required String email, required String amount, required String currency, required String cardId}) Future
toString() String
A string representation of this object.
inherited
verifyTransaction({required String tnxRef}) Future
virtualAccount({required String tnxRef}) Future

Operators

operator ==(Object other) bool
The equality operator.
inherited