PaymentChannelController class

Constructors

PaymentChannelController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

cardRequest({required String publicKey, required String email, required String authData, required String currency}) Future
getQRCodePaymentStatus({required String publicKey, required String tnxRef}) Future
getUSSDPaymentStatus({required String publicKey, required String tnxRef}) Future
initializePayment({required String publicKey, required String email, required int amount, required String currency}) Future
initializeQRCodePayment({required String publicKey, required String merchantRef}) Future
payWithUSSD({required String publicKey, required String tnxRef}) Future
recurringPaymentWithCard({required String publicKey, required String email, required String cardId, required String currency}) Future